@@ -1,12 +1,29 @@
+## To be cached by .onLoad()
+FutureRegistry <- NULL
+
 .onLoad <- function(libname, pkgname) {
-  inRCmdCheck <- import_future("inRCmdCheck")
+  ## Import private functions from 'future'
+  FutureRegistry <<- import_future("FutureRegistry")
+  
+  debug <- getOption("future.debug", FALSE)
+  
+  inRCmdCheck <- import_parallelly("inRCmdCheck")
   if (inRCmdCheck()) {
     ## Don't write to current working directory when running R CMD check.
-    path <- Sys.getenv("R_FUTURE_CACHE_PATH", file.path(tempdir(), ".future"))
-    Sys.setenv("R_FUTURE_CACHE_PATH" = path)
+    path <- Sys.getenv("R_FUTURE_CACHE_PATH", NA_character_)
+    if (is.na(path)) {
+      Sys.setenv("R_FUTURE_CACHE_PATH" = file.path(tempdir(), ".future"))
+      if (debug) {
+        mdebugf("R CMD check detected: Set R_FUTURE_CACHE_PATH=%s",
+                sQuote(Sys.getenv("R_FUTURE_CACHE_PATH")))
+      }
+    }
   }
+
+  update_package_options(debug = debug)
 }
 
+
 #' @importFrom utils file_test
 .onUnload <- function(libpath) {
   ## (a) Force finalizer of Future objects to run such
